@@ -63,37 +63,8 @@ class Dao(Generic[ModelType]):
         self.now = datetime.now().replace(tzinfo=utc)
 
     def __exclude_none_from_dict(self, data: dict) -> dict:
-        """
-        Remove None values from a dictionary.
-
-        Args:
-            data (dict): The input dictionary.
-
-        Returns:
-            dict: A new dictionary with None values removed.
-        """
         return {k: v for k, v in data.items() if v is not None}
 
-    def __populate_to_create(self, obj_data: Dict[str, Any]):
-        """
-        Populate a new model instance with data for creation.
-
-        Args:
-            obj_data (Dict[str, Any]): The data to populate the model with.
-
-        Returns:
-            int: The ID of the newly created model instance.
-        """
-        self.model = self.model_class(**obj_data)
-        self.model.created_at = self.now
-        self.model.updated_at = self.now
-        if hasattr(self.model, "archived"):
-            self.model.archived = 0
-
-        self.db_session.add(self.model)
-        self.db_session.commit()
-        return self.model.id
-
     def __populate_to_update(self, obj_db, obj_data: Dict[str, Any]):
         """
         Update an existing model instance with new data.
@@ -151,7 +122,16 @@ class Dao(Generic[ModelType]):
             Exception: If there's an error during creation, including duplicate entries.
         """
         try:
-            return self.__populate_to_create(obj_data)
+            self.model = self.model_class(**obj_data)
+            self.model.created_at = self.now
+            self.model.updated_at = self.now
+            if hasattr(self.model, "archived"):
+                self.model.archived = 0
+
+            self.db_session.add(self.model)
+            self.db_session.commit()
+            return self.model.id
+
         except SQLAlchemyError as e:
             if "1062" in str(e):
                 duplicate_values = (
